@@ -1263,73 +1263,6 @@ identical_ts!(
     "
 );
 
-identical_ts!(
-    ts_resolver_003,
-    "
-    class Foo<T> {}
-    class A {}
-    class B {}
-    new Foo<A>();
-    new Foo<B>();
-    "
-);
-
-to_ts!(
-    ts_resolver_class_constructor,
-    "
-class G<T> {}
-class Foo {
-    constructor() {
-        class Foo {
-            
-        }
-
-        new G<Foo__2>();
-    }
-}
-new G<Foo>();
-",
-    "
-class G<T> {
-}
-class Foo {
-    constructor(){
-        class Foo__2 {
-        }
-        new G<Foo__2>();
-    }
-}
-new G<Foo>();
-        "
-);
-
-to_ts!(
-    ts_resolver_class_getter,
-    "
-class G<T> {}
-class Foo {
-    get foo() {
-        class Foo {
-            
-        }
-
-        new G<Foo>();
-    }
-}
-",
-    "
-class G<T> {
-}
-class Foo {
-    get foo() {
-        class Foo__2 {
-        }
-        new G<Foo__2>();
-    }
-}
-    "
-);
-
 to_ts!(
     ts_resolver_nested_interface,
     "
@@ -2136,84 +2069,6 @@ to_ts!(
     "
 );
 
-to_ts!(
-    generic_call_type_argument_inference,
-    "
-    class C<T, U> {
-        constructor(public t: T, public u: U) {
-        }
-    
-        foo(t: T, u: U) {
-            return t;
-        }
-    
-        foo2(t: T, u: U) {
-            return u;
-        }
-    
-        foo3<T>(t: T, u: U) {
-            return t;
-        }
-    
-        foo4<U>(t: T, u: U) {
-            return t;
-        }
-    
-        foo5<T,U>(t: T, u: U) {
-            return t;
-        }
-    
-        foo6<T, U>() {
-            var x: T;
-            return x;
-        }
-    
-        foo7<T, U>(u: U) {
-            var x: T;
-            return x;
-        }
-    
-        foo8<T, U>() {
-            var x: T;
-            return x;
-        }
-    }    
-    ",
-    "
-    class C<T, U> {
-        constructor(public t__2: T, public u__2: U){
-        }
-        foo(t__3: T, u__3: U) {
-            return t__3;
-        }
-        foo2(t__4: T, u__4: U) {
-            return u__4;
-        }
-        foo3<T__5>(t__5: T__5, u__5: U) {
-            return t__5;
-        }
-        foo4<U__6>(t__6: T, u__6: U__6) {
-            return t__6;
-        }
-        foo5<T__7, U__7>(t__7: T__7, u__7: U__7) {
-            return t__7;
-        }
-        foo6<T__8, U__8>() {
-            var x__8: T__8;
-            return x__8;
-        }
-        foo7<T__9, U__9>(u__9: U__9) {
-            var x__9: T__9;
-            return x__9;
-        }
-        foo8<T__10, U__10>() {
-            var x__10: T__10;
-            return x__10;
-        }
-    }
-    "
-);
-
 to_ts!(
     generated_contextual_typing_01,
     "
